<template>
  <div class="app-container">
    <el-card class="box-card" shadow="never" style="width: 100%">
      <!--搜索条件-->
      <div class="filter-container">
        <my-search ref="searchBar" :items="items" @search="fifterForm"></my-search>
      </div>
      <div style="margin-top: 15px">
        <!--列表-->
        <my-table-v2 ref="myTable" :filter="filterFrom" :table="table"/>
      </div>

    </el-card>
  </div>
</template>

<script>
import MyTableV2 from "@/components/myTable/myTableV2";
import SettingIplatform from "@/utils/settingIplatform";
import {LongToDateTime} from "@/utils/DateFormatter";

export default {
  components: {MyTableV2},
  data() {
    return {
      items: [
        {
          type: 'text',
          dataIndex: 'userName',
          label: '登录账号',
          placeholder: '请输入',
          defaultValue: ''
        }
      ],
      // 搜索条件
      filterFrom: {
        userName: null,
      },
      // 表格数据
      table: {
        showIndex: true, // 是否显示序号
        expand: false, // 是否显示详情数据
        url: SettingIplatform.apiBaseURL + '/pc/p/login/info/list', // 请求地址
        // 工具条
        tools: {
          columnsCtrl: {// 列控制按钮
            show: false
          },
          generalExport: {// 通用导出按钮
            show: false
          },
          // 自定义工具条按钮
          custom: []
        },
        // 列信息
        columns: [
          {title: '登录账号', field: 'userName', align: 'left', minWidth: 110},
          {title: '登录IP', field: 'ipaddr', align: 'center'},
          {title: '浏览器类型', field: 'browser', align: 'center'},
          {
            title: '登录状态', field: 'status', align: 'center', formatter: row => {
              return {value: row.status == 1 ? '登录成功' : '登录失败'}
            }
          },
          {title: '提示消息', field: 'msg', align: 'left'},
          {
            title: '访问时间', field: 'login_time', align: 'center', width: 180, formatter: row => {
              return {value: LongToDateTime(row.loginTime)}
            }
          },
        ],
        // 操作信息
        operation: {
          show: false, // 显示操作列
        },
        paging: {
          show: true, // 显示分页
          // 分页信息
          page: {
            small: false,
            pageNumber: 1,
            pageSize: 10,
            total: 0
          }
        }
      },
    }
  },
  mounted() {
  },
  methods: {

    // 查询table列表
    search(pageNumber) {
      if (pageNumber != undefined) {
        this.$refs.myTable.search(pageNumber)
      } else {
        this.$refs.myTable.search()
      }
    },
    fifterForm(params) {
      this.filterFrom = Object.assign(this.filterFrom, params)
      this.search(1)
    },
  }
}
</script>

<style scoped>

</style>
